package com.ruoyi.ems.controller;

import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.web.page.TableDataInfo;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.ems.domain.PowerBox;
import com.ruoyi.ems.service.IPowerBoxService;
import io.swagger.annotations.Api;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 动力箱柜Controller
 *
 * @author ruoyi
 * @date 2024-08-20
 */
@RestController
@RequestMapping("/powerBox")
@Api(value = "PowerBoxController", description = "动力箱/配电箱管理")
public class PowerBoxController extends BaseController
{
    @Autowired
    private IPowerBoxService admPowerBoxService;

    /**
     * 查询动力箱柜列表
     */
    @GetMapping("/list")
    public TableDataInfo list(PowerBox powerBox)
    {
        startPage();
        List<PowerBox> list = admPowerBoxService.selectPowerBoxList(powerBox);
        return getDataTable(list);
    }

    /**
     * 导出动力箱柜列表
     */
    @RequiresPermissions("ems:powerBox:export")
    @Log(title = "动力箱柜", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PowerBox admPowerBox)
    {
        List<PowerBox> list = admPowerBoxService.selectPowerBoxList(admPowerBox);
        ExcelUtil<PowerBox> util = new ExcelUtil<PowerBox>(PowerBox.class);
        util.exportExcel(response, list, "动力箱柜数据");
    }

    /**
     * 获取动力箱柜详细信息
     */
    @RequiresPermissions("ems:powerBox:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(admPowerBoxService.selectPowerBoxById(id));
    }

    /**
     * 新增动力箱柜
     */
    @RequiresPermissions("ems:powerBox:add")
    @Log(title = "动力箱柜", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PowerBox admPowerBox)
    {
        return toAjax(admPowerBoxService.insertPowerBox(admPowerBox));
    }

    /**
     * 修改动力箱柜
     */
    @RequiresPermissions("ems:powerBox:edit")
    @Log(title = "动力箱柜", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PowerBox admPowerBox)
    {
        return toAjax(admPowerBoxService.updatePowerBox(admPowerBox));
    }

    /**
     * 删除动力箱柜
     */
    @RequiresPermissions("ems:powerBox:remove")
    @Log(title = "动力箱柜", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(admPowerBoxService.deletePowerBoxByIds(ids));
    }
}
